summaryrefslogtreecommitdiffstats
path: root/src/knutdock.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:37:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:37:31 -0600
commite1cddce9af7ab2eeaa5613e91e6899128b1ce5ab (patch)
treebc87855cfcaadc07220903dacdfa454c2db386e1 /src/knutdock.cpp
parentc895c15390ccba4dea8848a6eef98c7a4527c4e3 (diff)
downloadknutclient-e1cddce9af7ab2eeaa5613e91e6899128b1ce5ab.tar.gz
knutclient-e1cddce9af7ab2eeaa5613e91e6899128b1ce5ab.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'src/knutdock.cpp')
-rwxr-xr-xsrc/knutdock.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/knutdock.cpp b/src/knutdock.cpp
index 61f67d8..bb1f6e1 100755
--- a/src/knutdock.cpp
+++ b/src/knutdock.cpp
@@ -195,7 +195,7 @@ void KNutDock::repaintDock (const bool always) {
TQPainter paint;
- if (m_activeUpsInfo->upsNet == 0) { tqrepaint(); return;}
+ if (m_activeUpsInfo->upsNet == 0) { repaint(); return;}
m_dataOkOld=m_dataOk;
@@ -230,7 +230,7 @@ void KNutDock::repaintDock (const bool always) {
// **********RUNTIME***********
myStatusBatValue = myStatusValue & KNutNet::OB; // OB = UPS runs on battery
if ((myRuntimeValue != m_runtimeValue) || (myStatusBatValue != m_statusBatValue)) {
// when runtime is changed or flags OB is changed we must tqrepaint icons
// when OB is changed same items in icon will change color
m_runtimeValue = myRuntimeValue; // runtime is old value of runtime, one is defined like global value of class
m_statusBatValue = myStatusBatValue;
@@ -390,7 +390,7 @@ void KNutDock::repaintDock (const bool always) {
}
}
}
- tqrepaint();
+ repaint();
}
@@ -483,17 +483,17 @@ void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad
if (m_toolTipFlags & TTRun) {
if (runtime != knc::numberVarError)
- text += "\n" + i18n("Runtime") + i18n(" : %1:%2 min").tqarg(min).tqarg(sec);
+ text += "\n" + i18n("Runtime") + i18n(" : %1:%2 min").arg(min).arg(sec);
}
if (m_toolTipFlags & TTCharge) {
if (batteryCharge != knc::numberVarError)
- text += "\n" + i18n("Battery Charge") + TQString(" : %1 %").tqarg(batteryCharge);
+ text += "\n" + i18n("Battery Charge") + TQString(" : %1 %").arg(batteryCharge);
}
if (m_toolTipFlags & TTLoad) {
if (upsLoad != knc::numberVarError)
- text += "\n" + i18n("UPS Load") + TQString(" : %1 %").tqarg(upsLoad);
+ text += "\n" + i18n("UPS Load") + TQString(" : %1 %").arg(upsLoad);
}
TQToolTip::remove(this);
@@ -230,7 +230,7 @@ void KNutDock::repaintDock (const bool always) {
myStatusBatValue = myStatusValue & KNutNet::OB; // OB = UPS runs on battery
if ((myRuntimeValue != m_runtimeValue) || (myStatusBatValue != m_statusBatValue)) {
- // when runtime is changed or flags OB is changed we must tqrepaint icons
+ // when runtime is changed or flags OB is changed we must repaint icons
// when OB is changed same items in icon will change color
m_runtimeValue = myRuntimeValue; // runtime is old value of runtime, one is defined like global value of class